@@ -26,7 +26,7 @@ from dagster.utils.merger import merge_dicts
 from dagster.utils.yaml_utils import load_yaml_from_globs
 
 from .config import DAGSTER_CONFIG_YAML_FILENAME
-from .ref import InstanceRef, compute_logs_directory
+from .ref import InstanceRef
 
 # 'airflow_execution_date' and 'is_airflow_ingest_pipeline' are hardcoded tags used in the
 # airflow ingestion logic (see: dagster_pipeline_factory.py). 'airflow_execution_date' stores the
@@ -213,7 +213,7 @@ class DagsterInstance:
         from dagster.core.storage.event_log import InMemoryEventLogStorage
         from dagster.core.storage.root import LocalArtifactStorage
         from dagster.core.storage.runs import InMemoryRunStorage
-        from dagster.core.storage.local_compute_log_manager import NoOpComputeLogManager
+        from dagster.core.storage.noop_compute_log_manager import NoOpComputeLogManager
 
         if tempdir is None:
             tempdir = DagsterInstance.temp_storage()
@@ -223,7 +223,7 @@ class DagsterInstance:
             local_artifact_storage=LocalArtifactStorage(tempdir),
             run_storage=InMemoryRunStorage(),
             event_storage=InMemoryEventLogStorage(),
-            compute_log_manager=NoOpComputeLogManager(compute_logs_directory(tempdir)),
+            compute_log_manager=NoOpComputeLogManager(),
         )
 
     @staticmethod
@@ -802,17 +802,28 @@ class DagsterInstance:
 
     # Scheduler
 
-    def start_schedule(self, repository, schedule_name):
-        return self._scheduler.start_schedule(self, repository, schedule_name)
+    def reconcile_scheduler_state(self, python_path, repository_path, repository):
+        return self._scheduler.reconcile_scheduler_state(
+            self, repository, python_path, repository_path
+        )
 
-    def stop_schedule(self, repository, schedule_name):
-        return self._scheduler.stop_schedule(self, repository, schedule_name)
+    def start_schedule_and_update_storage_state(self, repository, schedule_name):
+        return self._scheduler.start_schedule_and_update_storage_state(
+            self, repository, schedule_name
+        )
 
-    def end_schedule(self, repository, schedule_name):
-        return self._scheduler.end_schedule(self, repository, schedule_name)
+    def stop_schedule_and_update_storage_state(self, repository, schedule_name):
+        return self._scheduler.stop_schedule_and_update_storage_state(
+            self, repository, schedule_name
+        )
 
-    def running_job_count(self, repository_name, schedule_name):
-        return self._scheduler.running_job_count(repository_name, schedule_name)
+    def stop_schedule_and_delete_from_storage(self, repository, schedule_name):
+        return self._scheduler.stop_schedule_and_delete_from_storage(
+            self, repository, schedule_name
+        )
+
+    def running_schedule_count(self, repository_name, schedule_name):
+        return self._scheduler.running_schedule_count(repository_name, schedule_name)
 
     def scheduler_debug_info(self):
         from dagster.core.scheduler import SchedulerDebugInfo, ScheduleStatus
@@ -822,14 +833,14 @@ class DagsterInstance:
         schedule_info = self.all_schedules_info()
         schedules = []
         for repository_name, schedule in schedule_info:
-            if schedule.status == ScheduleStatus.RUNNING and not self.running_job_count(
+            if schedule.status == ScheduleStatus.RUNNING and not self.running_schedule_count(
                 repository_name, schedule.name
             ):
                 errors.append(
                     "Schedule {schedule_name} is set to be running, but the scheduler is not "
                     "running the schedule.".format(schedule_name=schedule.name)
                 )
-            elif schedule.status == ScheduleStatus.STOPPED and self.running_job_count(
+            elif schedule.status == ScheduleStatus.STOPPED and self.running_schedule_count(
                 repository_name, schedule.name
             ):
                 errors.append(
@@ -837,7 +848,7 @@ class DagsterInstance:
                     "the schedule.".format(schedule_name=schedule.name)
                 )
 
-            if self.running_job_count(repository_name, schedule.name) > 1:
+            if self.running_schedule_count(repository_name, schedule.name) > 1:
                 errors.append(
                     "Duplicate jobs found: More than one job for schedule {schedule_name} are "
                     "running on the scheduler.".format(schedule_name=schedule.name)
